@@ -9,7 +9,7 @@ logger = logging.getLogger(__name__)
 
 class SummaryStub:
 
-    def __call__(self, data, playback=None, fallback=False):
+    def __call__(self, data, fallback=False):
         try:
             header = decompress(data)
             version, game, save, log = parse_version(header, data)
@@ -20,11 +20,11 @@ class SummaryStub:
         if supported and not fallback:
             logger.info("using model summary")
             try:
-                return ModelSummary(data, playback)
+                return ModelSummary(data)
             except RuntimeError as e:
                 logger.warning(f"could not fast parse; falling back: {e}")
         logger.info("using full summary")
-        return FullSummary(data, playback)
+        return FullSummary(data)
 
 
 Summary = SummaryStub()
